///////////////////////////////////////////////////////////////////////////////////////////////
// Nanodata.
// Copyright (C) 2023-2023 the original author or authors.
//
// This program is free software; you can redistribute it and/or
// modify it under the terms of the GNU General Public License
// as published by the Free Software Foundation; version 2
// of the License only.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program; if not, write to the Free Software
// Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
///////////////////////////////////////////////////////////////////////////////////////////////

package org.nanoboot.nanodata.entity;

import lombok.AllArgsConstructor;
import lombok.Data;
import lombok.ToString;


/**
 *
 * @author <a href="mailto:robertvokac@nanoboot.org">Robert Vokac</a>
 * @since 0.0.0
 */
@Data
@AllArgsConstructor
@ToString
public class Statement implements Comparable<Statement>{

    private String id;
    private String value;
    private String source;
    private String target;
    private String createdAt;
    private String flags;

    @Override
    public int compareTo(Statement o) {
        String flags1 = this.flags == null ? "" : this.flags;
        String flags2 = o.flags == null ? "" : o.flags;
        if(flags1.isBlank() && !flags2.isBlank()) {
            return -1;
        }
        if(!flags1.isBlank() && flags2.isBlank()) {
            return 1;
        }
        
        if(flags1.isBlank() && flags2.isBlank()) {
            return 0;
        }
        if(!flags1.isBlank() && !flags2.isBlank()) {
            Integer flags1Int = switch(flags1) {
                case HIGHEST -> 5;
                case HIGH -> 4;
                case MEDIUM -> 3;
                case LOW -> 2;
                case LOWEST -> 1;
                case NONE -> 0;
                default -> 3;
            };
            Integer flags2Int = switch(flags2) {
                case HIGHEST -> 5;
                case HIGH -> 4;
                case MEDIUM -> 3;
                case LOW -> 2;
                case LOWEST -> 1;
                case NONE -> 0;
                default -> 3;
            };
            return flags1Int.compareTo(flags2Int);
        }
        return 0;
    }
    private static final String HIGHEST = "highest";
    private static final String HIGH = "high";
    private static final String MEDIUM = "medium";
    private static final String LOW = "low";
    private static final String LOWEST = "lowest";
    private static final String NONE = "none";
    
}
